@@ -26,16 +26,23 @@ def main():
 
     if api.check_login():
 
-        panelen = api.requestListOfAllPanels().ReturnAllPanelsIds()
+        alles = api.requestAllData()
 
-        for paneel in panelen:
-            data = api.requestSystemData(paneel.split('|')[0])
+        #wtf = api.getLifeTimeEnergy()
+        #print(wtf)
+        for paneel in alles:
+            print(paneel.lifetime_energy)
 
-            datum = data.lastmeasurement
+        #panelen = api.requestListOfAllPanels().ReturnAllPanelsIds()
 
-            print(datum)
+        #for paneel in panelen:
+#            data = api.requestSystemData(paneel.split('|')[0])
 
-            exit()
+#            datum = data.lastmeasurement
+
+ #           print(datum)
+
+  #          exit()
 
 
 
